@@ -3,7 +3,7 @@ template_find <- function(base_path, template_name) {
   path_exists <- file.exists(path)
 
   if (!any(path_exists)) {
-    stop("Can not find template ", template_name, call. = FALSE)
+    stop("Can't find template '", template_name, "'", call. = FALSE)
   }
 
   path[path_exists][1]
@@ -16,7 +16,8 @@ template_eval <- function(template_path, vars) {
 process_templates <- function(block, base_path, global_options = list()) {
   template_locs <- names(block) == "template"
   template_tags <- block[template_locs]
-  if (length(template_tags) == 0) return(block)
+  if (length(template_tags) == 0)
+    return(block)
 
   templates <- unlist(template_tags, use.names = FALSE)
   paths <- vapply(templates, template_find, base_path = base_path,
@@ -28,13 +29,15 @@ process_templates <- function(block, base_path, global_options = list()) {
   vars <- lapply(vars, utils::type.convert, as.is = TRUE)
 
   results <- lapply(paths, template_eval, vars = list2env(vars))
+  tokens <- lapply(results, tokenise_block, file = "TEMPLATE", offset = 0L)
 
   # Insert templates back in the location where they came from
-  block_pieces <- lapply(block, list)
-  block_pieces[template_locs] <- lapply(results, parse_block,
-    file = "TEMPLATE", registry = roclet_tags.roclet_rd(list()), offset = 0L,
-    global_options = global_options)
-  names(block_pieces)[template_locs] <- ""
+  tags <- lapply(block, list)
+  tags[template_locs] <- lapply(tokens, parse_tags,
+    registry = roclet_tags.roclet_rd(list()),
+    global_options = global_options
+  )
+  names(tags)[template_locs] <- ""
 
-  unlist(block_pieces, recursive = FALSE)
+  roxy_block_copy(block, unlist(tags, recursive = FALSE))
 }
